A list — mosaik 2.3.1 documentation

Important

wanna play a game?

- inside

- this

  - list

  - `in the world`

    - hi

    - his

      hi

# A list

- here - is - some

  > - list
  > - items
  > - yahoo
  > - `huh`

- how

- `inline literall`

- `inline literall`

- `inline literall`

## Second list level

- here is a list in a second-level section.

- yahoo

- yahoo

  - yahoo

  - here is an inner bullet `oh`

    - one more `with an inline literally`. yahoo

      heh heh. child. try to beat this embed:

           1
           2
           3
           4
           5
           6
           7
           8
           9
          10
          # -*- coding: utf-8 -*-
          """Test Module for sphinx_rtd_theme."""

          class Foo:

              r"""Docstring for class Foo.

              This text tests for the formatting of docstrings generated from output
              ``sphinx.ext.autodoc``. Which contain reST, but sphinx nests it in the

  - and another. yahoo

  - yahoo

  - `hi`

- and hehe

### But deeper down the rabbit hole

- I kept saying that, “deeper down the rabbit hole”. yahoo
  - I cackle at night yahoo.
- I’m so lonely here in GZ `guangzhou`
- A man of python destiny, hopes and dreams. yahoo
  - yahoo
    - yahoo `hi`
    - `destiny`